@@ -13,8 +13,8 @@
 
 #include "cogl-enum-types.h"
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-material-compat.h" */
-#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-material-compat.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/deprecated/cogl-material-compat.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/deprecated/cogl-material-compat.h"
 
 GType
 cogl_material_filter_get_type (void)
@@ -115,8 +115,8 @@ cogl_material_layer_type_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-shader.h" */
-#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/deprecated/cogl-shader.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/deprecated/cogl-shader.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/deprecated/cogl-shader.h"
 
 GType
 cogl_shader_type_get_type (void)
@@ -141,8 +141,8 @@ cogl_shader_type_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-bitmap.h" */
-#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-bitmap.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-bitmap.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-bitmap.h"
 
 GType
 cogl_bitmap_error_get_type (void)
@@ -168,8 +168,8 @@ cogl_bitmap_error_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-texture.h" */
-#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-texture.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-texture.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-texture.h"
 
 GType
 cogl_texture_error_get_type (void)
@@ -244,8 +244,8 @@ cogl_texture_components_get_type (void)
   return g_enum_type_id__volatile;
 }
 
-/* enumerations from "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-types.h" */
-#include "/usr/src/ports/cogl/cogl-1.22.0-1.x86_64/src/cogl-1.22.0/cogl/cogl-types.h"
+/* enumerations from "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-types.h" */
+#include "/usr/src/ports/cogl/cogl-1.22.2-1.i686/src/cogl-1.22.2/cogl/cogl-types.h"
 
 GType
 cogl_pixel_format_get_type (void)
